==> gnome-core-0.27.tar.gz: gnome-core-0.27/applets/diskusage/diskusage_read.c <==
#include "diskusage.h"
#include "mountlist.h"
#include "fsusage.h"

#include <stdio.h>
#include <unistd.h>

#include <assert.h>

/* #define DU_DEBUG  */

/* Many systems reserve some space on each filesystem that only the superuser
 * can use. Set this to true if you want count this space towards the among of
 * free space. This would be the opposite of what 'df' does. */
#undef ADD_RESERVED_SPACE

void
diskusage_read (DiskusageInfo *ps)
{
	unsigned i = 0;
	struct mount_entry *mount_list, *me;
	struct fs_usage fsu;
	
	/* Get list of currently mounted filesystems. */
	
	mount_list = read_filesystem_list (0, 0);
	
	assert (mount_list != NULL);

	for (me = mount_list; me; me = me->me_next) {
#ifdef DU_DEBUG
		printf("Filesystem: %p - %s - %s - %c\n",
		       me->me_devname, me->me_mountdir, me->me_type);
#endif
		
		assert (get_fs_usage (me->me_mountdir, me->me_devname, &fsu) == 0);
		
		fsu.fsu_blocks /= 2;
		fsu.fsu_bfree /= 2;
		fsu.fsu_bavail /= 2;
		
		if (fsu.fsu_blocks == 0)
			continue;

		/*
		 * copy dev_name and mount_dir strings
		 */
		if ((ps->filesystems + i)->dev_name)
			free ((ps->filesystems + i)->dev_name);
		(ps->filesystems + i)->dev_name = 
			g_new(gchar, strlen (me->me_devname)+1);
		strcpy ((ps->filesystems + i)->dev_name, 
				me->me_devname);

		if ((ps->filesystems + i)->mount_dir)
			free ((ps->filesystems + i)->mount_dir);
		(ps->filesystems + i)->mount_dir = 
			g_new(gchar, strlen (me->me_mountdir)+1);
		strcpy ((ps->filesystems + i)->mount_dir, 
				me->me_mountdir);


		ps->filesystems[i].sizeinfo [DU_FS_TOTAL] =
			fsu.fsu_blocks;
#ifdef ADD_RESERVED_SPACE
		ps->filesystems[i].sizeinfo [DU_FS_FREE] =
			fsu.fsu_bfree;
#else
		ps->filesystems[i].sizeinfo [DU_FS_FREE] =
			fsu.fsu_bavail;
#endif
		ps->filesystems[i].sizeinfo [DU_FS_USED] =
			fsu.fsu_blocks - fsu.fsu_bfree;

#ifdef DU_DEBUG
		printf("Usage: %ld, %ld, %ld\n",
		       ps->filesystems[i].sizeinfo [DU_FS_TOTAL],
		       ps->filesystems[i].sizeinfo [DU_FS_FREE],
		       ps->filesystems[i].sizeinfo [DU_FS_USED]);
#endif
		
		i++;

		/* FIXME
		 * need to make a linked listfor ps->filesystems, to
		 * get rid of hardcoded arraysize
		 */
		if (i >= DU_MAX_FS)
			continue;
	}

	ps->n_filesystems = i;

	me = mount_list;
	while (me) {
		mount_list = me;
		me = me->me_next;
		if(mount_list->me_devname)
			free(mount_list->me_devname);
		if(mount_list->me_mountdir)
			free(mount_list->me_mountdir);
		if(mount_list->me_type)
			free(mount_list->me_type);
		free(mount_list);
	}
	
#ifdef DU_DEBUG
	printf("n_filesystems = %u \n", i);
#endif
}

==> gnome-core-0.99.3.2.tar.gz: gnome-core-0.99.3.2/applets/diskusage/diskusage_read.c <==
#include <glibtop.h>
#include <glibtop/fsusage.h>
#include <glibtop/mountlist.h>

#include "diskusage.h"

#include <stdio.h>
#include <unistd.h>

#include <assert.h>

/* #define DU_DEBUG */

/* Many systems reserve some space on each filesystem that only the superuser
 * can use. Set this to true if you want count this space towards the among of
 * free space. This would be the opposite of what 'df' does. */
#undef ADD_RESERVED_SPACE

void
diskusage_read (DiskusageInfo *ps)
{
	glibtop_fsusage fsu;
	glibtop_mountlist mountlist;
	glibtop_mountentry *mount_list;
	unsigned i = 0, index;
	
	/* Get list of currently mounted filesystems. */
	
	mount_list = glibtop_get_mountlist (&mountlist, 0);

	assert (mount_list != NULL);

	for (index = 0; index < mountlist.number; index++) {
#ifdef DU_DEBUG
#if 0
		printf ("Mount_Entry (%d): %-30s %-10s %-20s\n", index,
			mount_list [index].mountdir,
			mount_list [index].type,
			mount_list [index].devname);
#endif
#endif
		
		glibtop_get_fsusage (&fsu, mount_list [index].mountdir);

#if 0		
		assert (fsu.flags != 0);
#endif
		
		fsu.blocks /= 2;
		fsu.bfree /= 2;
		fsu.bavail /= 2;
		
		if (fsu.blocks == 0)
			continue;

		/*
		 * copy dev_name and mount_dir strings
		 */
		if ((ps->filesystems + i)->dev_name)
			free ((ps->filesystems + i)->dev_name);
		(ps->filesystems + i)->dev_name = 
			g_new(gchar, strlen (mount_list [index].devname)+1);
		strcpy ((ps->filesystems + i)->dev_name, 
				mount_list [index].devname);

		if ((ps->filesystems + i)->mount_dir)
			free ((ps->filesystems + i)->mount_dir);
		(ps->filesystems + i)->mount_dir = 
			g_new(gchar, strlen (mount_list [index].mountdir)+1);
		strcpy ((ps->filesystems + i)->mount_dir, 
				mount_list [index].mountdir);


		ps->filesystems[i].sizeinfo [DU_FS_TOTAL] =
			fsu.blocks;
#ifdef ADD_RESERVED_SPACE
		ps->filesystems[i].sizeinfo [DU_FS_FREE] =
			fsu.bfree;
#else
		ps->filesystems[i].sizeinfo [DU_FS_FREE] =
			fsu.bavail;
#endif
		ps->filesystems[i].sizeinfo [DU_FS_USED] =
			fsu.blocks - fsu.bfree;

#ifdef DU_DEBUG
		printf("Usage: %ld, %ld, %ld\n",
		       ps->filesystems[i].sizeinfo [DU_FS_TOTAL],
		       ps->filesystems[i].sizeinfo [DU_FS_FREE],
		       ps->filesystems[i].sizeinfo [DU_FS_USED]);
#endif
		
		/* FIXME
		 * need to make a linked listfor ps->filesystems, to
		 * get rid of hardcoded arraysize
		 */
		if (i >= DU_MAX_FS)
			continue;

		i++;
	}

	ps->n_filesystems = i;

	free (mount_list);
	
#ifdef DU_DEBUG
	printf("n_filesystems = %u \n", i);
#endif
}
